minigrep
minigrep is a small CLI implementation of the grep command, written in Rust.
This crate follows the tutorial laid out in Chapter 12 of The Book
Structs
- Config
- A fully valid
minigrepcommand. Consists of aqueryto search for, afilenameto search within, and acase_sensitiveboolean to specify whether the search should ignore case or not
Functions
- run
- Given a valid
configof arguments, run the minigrep application. This is the functional entry-point into the application. - search
- search through each line in given
contentsand return any lines containing a match to thequery - search_
case_ insensitive - search through each line in given
contentsand return any lines containing a case-insensitive match to thequery.